import sys
import argparse
from pathlib import Path
import os
import numpy as np
import ast

def main():
    parser = argparse.ArgumentParser("imface cli for image vector")
    parser.add_argument("--represent", help="represent image embed vector", default=False)
    parser.add_argument("-v", "--version", help="version", default=False, action="store_true")
    parser.add_argument("--extract", help="extract face, and only allowed to extrace one face, inset the image path", default=False)
    parser.add_argument("--treshold", help="get treshold", default=False, action="store_true")
    #generate image album
    subparsers = parser.add_subparsers(dest="command")

    generate_parser = subparsers.add_parser("generate-crop-img")
    generate_parser.add_argument("-p", "--path", help="path to image file", required=True)
    generate_parser.add_argument("-o", "--output", help="directory to save image", required=True)
    
    args = parser.parse_args()

    version =  "0.0.0.2.9"
    if args.version:
        os.environ.setdefault("DEEPFACE_HOME", "/app")
        print(version + str(os.getenv("DEEPFACE_HOME", default=str(Path.home()))))
        exit(0)

    elif args.represent:
        target_image = Path(args.represent)

        try:
            os.environ.setdefault("DEEPFACE_HOME", "/app")

            from imface.utils import deepface_util as utils
            embed = utils.getEmbeddingVector(str(target_image))
            print(embed)
        except Exception as e:
            print("error " + repr(e))
            raise SystemExit(1)

    elif args.extract:
        target_image = Path(args.extract)
        try:
            os.environ.setdefault("DEEPFACE_HOME", "/app")
            
            from imface.utils import deepface_util as utils
            data = utils.extractFace(str(target_image))
            if len(data) > 1:
                print("error only allowed one face")
                raise SystemExit(1)
            else:
                print(data[0]['embedding'])
        except Exception as e:
            print("error" + repr(e))
            raise SystemExit(1)

    elif args.command == "generate-crop-img":
        if args.path and args.output:
            try:
                os.environ.setdefault("DEEPFACE_HOME", "/app")
                
                from imface.utils import deepface_util as utils
                file_names = utils.generate_faces_image(path=args.path, album_dir=args.output)
                print(file_names)
            except Exception as e:
                print("error " + repr(e))
                raise SystemExit(1)

    if __name__ == "__main__":
        main()